##  Monitor Progress Using Metrics
To monitor progress, use the following metrics on the onboarding dashboard for enterprise architects. For additional information, see [Understanding Best-Practice Metrics](https://help.sap.com/docs/leanix/ea/application-portfolio-management-onboarding-dashboard-for-enterprise-architects?locale=en-US&state=PRODUCTION&version=CLOUD#loio2758a23c7a441014b785d6548482893a__understanding_best_practice_metrics).
Metrics for Relations Metric | Explanation
---|---
At least 20 applications* are linked to business capabilities. | Establishing accurate relations is crucial for deriving meaningful insights from reports. The metric does not cover relations between application fact sheets of the deployment subtype and organization fact sheets. To learn more, see [Application Fact Sheet Subtypes](https://help.sap.com/docs/leanix/ea/application-modeling-guidelines?locale=en-US&state=PRODUCTION&version=CLOUD#loio275892ca7a441014ab86c9b2e6382a33__application_fact_sheet_subtypes).
At least 20 applications* are linked to organizations.


*Count all application fact sheets where the subtype is business application or empty.
